@@ -18,18 +18,20 @@ main_path = '/home/pi/class/'  # 读取和保存文件所用主文件夹
 if 'win' in system_platform:
     import mediapipe as mp
     # 获取当前文件的位置
-    file_path = os.path.join(os.getcwd().split('blockly-electron')[0],'blockly-electron')
-    main_path = file_path + '\\resources\\assets\\class\\'
+    file_path = os.path.join(os.getcwd().split('blockly-electron')[0], 'blockly-electron')
+    if not os.path.exists(file_path):
+        if os.path.exists(os.path.join(os.getcwd(), "resources")):
+            file_path = os.getcwd()
+    main_path = os.path.join(file_path, 'resources', 'assets', 'class').replace("\\", "/")
 else:
     try:
         import mediapipe as mp
     except ImportError:
         os.system('sudo pip3 install mediapipe-rpi4')
-
-picture_path = main_path + 'picture/'  # 图片文件夹
-model_path = main_path + 'model/'  # 识别模型文件夹
-d_path = main_path + 'camera_pos/'
-dat_path = main_path + 'data/face_recognize/'
+picture_path =os.path.join( main_path , 'picture/')  # 图片文件夹
+model_path = os.path.join(main_path , 'model/')  # 识别模型文件夹
+d_path = os.path.join(main_path , 'camera_pos/')
+dat_path = os.path.join(main_path , 'data/face_recognize/')
 
 items_num = {0: '0', 1: '1', 2: '2', 3: '3',
              4: '4', 5: '5', 6: '6', 7: '7', 8: '8', 9: '9'}  # 方向数字指示牌
